# `main`

Run the Ultimate RVC web application.

**Usage**:

```console
$ main [OPTIONS]
```

**Options**:

* `-s, --share`: Enable sharing
* `-l, --listen`: Make the web application reachable from your local network.
* `-h, --listen-host TEXT`: The hostname that the server will use.
* `-p, --listen-port INTEGER`: The listening port that the server will use.
* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.
